@@ -1,7 +1,6 @@
 """
-****************
 ISMAGS Algorithm
-****************
+================
 
 Provides a Python implementation of the ISMAGS algorithm. [1]_
 
@@ -90,21 +89,21 @@ True
 
 Notes
 -----
- - The current implementation works for undirected graphs only. The algorithm
-   in general should work for directed graphs as well though.
- - Node keys for both provided graphs need to be fully orderable as well as
-   hashable.
- - Node and edge equality is assumed to be transitive: if A is equal to B, and
-   B is equal to C, then A is equal to C.
+- The current implementation works for undirected graphs only. The algorithm
+  in general should work for directed graphs as well though.
+- Node keys for both provided graphs need to be fully orderable as well as
+  hashable.
+- Node and edge equality is assumed to be transitive: if A is equal to B, and
+  B is equal to C, then A is equal to C.
 
 References
 ----------
-    .. [1] M. Houbraken, S. Demeyer, T. Michoel, P. Audenaert, D. Colle,
-       M. Pickavet, "The Index-Based Subgraph Matching Algorithm with General
-       Symmetries (ISMAGS): Exploiting Symmetry for Faster Subgraph
-       Enumeration", PLoS One 9(5): e97896, 2014.
-       https://doi.org/10.1371/journal.pone.0097896
-    .. [2] https://en.wikipedia.org/wiki/Maximum_common_induced_subgraph
+.. [1] M. Houbraken, S. Demeyer, T. Michoel, P. Audenaert, D. Colle,
+   M. Pickavet, "The Index-Based Subgraph Matching Algorithm with General
+   Symmetries (ISMAGS): Exploiting Symmetry for Faster Subgraph
+   Enumeration", PLoS One 9(5): e97896, 2014.
+   https://doi.org/10.1371/journal.pone.0097896
+.. [2] https://en.wikipedia.org/wiki/Maximum_common_induced_subgraph
 """
 
 __all__ = ["ISMAGS"]
@@ -184,8 +183,8 @@ def make_partitions(items, test):
 
 def partition_to_color(partitions):
     """
-    Creates a dictionary with for every item in partition for every partition
-    in partitions the index of partition in partitions.
+    Creates a dictionary that maps each item in each partition to the index of
+    the partition to which it belongs.
 
     Parameters
     ----------
@@ -196,7 +195,7 @@ def partition_to_color(partitions):
     -------
     dict
     """
-    colors = dict()
+    colors = {}
     for color, keys in enumerate(partitions):
         for key in keys:
             colors[key] = color
@@ -720,7 +719,7 @@ class ISMAGS:
             counts[node1][ecolor, node_colors[node2]] += 1
             counts[node2][ecolor, node_colors[node1]] += 1
 
-        node_edge_colors = dict()
+        node_edge_colors = {}
         for node in graph.nodes:
             node_edge_colors[node] = node_colors[node], set(counts[node].items())
 
@@ -849,11 +848,11 @@ class ISMAGS:
             left_to_map = to_be_mapped - set(mapping.keys())
 
             new_candidates = candidates.copy()
-            sgn_neighbours = set(self.subgraph[sgn])
-            not_gn_neighbours = set(self.graph.nodes) - set(self.graph[gn])
+            sgn_nbrs = set(self.subgraph[sgn])
+            not_gn_nbrs = set(self.graph.nodes) - set(self.graph[gn])
             for sgn2 in left_to_map:
-                if sgn2 not in sgn_neighbours:
-                    gn2_options = not_gn_neighbours
+                if sgn2 not in sgn_nbrs:
+                    gn2_options = not_gn_nbrs
                 else:
                     # Get all edges to gn of the right color:
                     g_edges = self._edges_of_same_color(sgn, sgn2)
@@ -883,10 +882,7 @@ class ISMAGS:
 
             # The next node is the one that is unmapped and has fewest
             # candidates
-            # Pylint disables because it's a one-shot function.
-            next_sgn = min(
-                left_to_map, key=lambda n: min(new_candidates[n], key=len)
-            )  # pylint: disable=cell-var-from-loop
+            next_sgn = min(left_to_map, key=lambda n: min(new_candidates[n], key=len))
             yield from self._map_nodes(
                 next_sgn,
                 new_candidates,
@@ -910,10 +906,7 @@ class ISMAGS:
         # "part of" the subgraph in to_be_mapped, and we make it a little
         # smaller every iteration.
 
-        # pylint disable because it's guarded against by default value
-        current_size = len(
-            next(iter(to_be_mapped), [])
-        )  # pylint: disable=stop-iteration-return
+        current_size = len(next(iter(to_be_mapped), []))
 
         found_iso = False
         if current_size <= len(self.graph):
