@@ -4,3 +4,5 @@ from networkx.utils.random_sequence import *
 from networkx.utils.union_find import *
 from networkx.utils.rcm import *
 from networkx.utils.heaps import *
+from networkx.utils.backends import *
+from networkx.utils.configs import *
